crikit.ui package
=================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   crikit.ui.utils

Submodules
----------

crikit.ui.classes\_ui module
----------------------------

.. automodule:: crikit.ui.classes_ui
   :members:
   :undoc-members:
   :show-inheritance:

crikit.ui.dialog\_AbstractFactorization module
----------------------------------------------

.. automodule:: crikit.ui.dialog_AbstractFactorization
   :members:
   :undoc-members:
   :show-inheritance:

crikit.ui.dialog\_AbstractPlotEffect module
-------------------------------------------

.. automodule:: crikit.ui.dialog_AbstractPlotEffect
   :members:
   :undoc-members:
   :show-inheritance:

crikit.ui.dialog\_AnscombeParams module
---------------------------------------

.. automodule:: crikit.ui.dialog_AnscombeParams
   :members:
   :undoc-members:
   :show-inheritance:

crikit.ui.dialog\_SVD module
----------------------------

.. automodule:: crikit.ui.dialog_SVD
   :members:
   :undoc-members:
   :show-inheritance:

crikit.ui.dialog\_kkOptions module
----------------------------------

.. automodule:: crikit.ui.dialog_kkOptions
   :members:
   :undoc-members:
   :show-inheritance:

crikit.ui.dialog\_model module
------------------------------

.. automodule:: crikit.ui.dialog_model
   :members:
   :undoc-members:
   :show-inheritance:

crikit.ui.dialog\_ploteffect module
-----------------------------------

.. automodule:: crikit.ui.dialog_ploteffect
   :members:
   :undoc-members:
   :show-inheritance:

crikit.ui.dialog\_save module
-----------------------------

.. automodule:: crikit.ui.dialog_save
   :members:
   :undoc-members:
   :show-inheritance:

crikit.ui.dialog\_subResidualOptions module
-------------------------------------------

.. automodule:: crikit.ui.dialog_subResidualOptions
   :members:
   :undoc-members:
   :show-inheritance:

crikit.ui.dialog\_varstabAnscombeOptions module
-----------------------------------------------

.. automodule:: crikit.ui.dialog_varstabAnscombeOptions
   :members:
   :undoc-members:
   :show-inheritance:

crikit.ui.helper\_plotOptions module
------------------------------------

.. automodule:: crikit.ui.helper_plotOptions
   :members:
   :undoc-members:
   :show-inheritance:

crikit.ui.helper\_roiselect module
----------------------------------

.. automodule:: crikit.ui.helper_roiselect
   :members:
   :undoc-members:
   :show-inheritance:

crikit.ui.main\_Mosaic module
-----------------------------

.. automodule:: crikit.ui.main_Mosaic
   :members:
   :undoc-members:
   :show-inheritance:

crikit.ui.widget\_ALS module
----------------------------

.. automodule:: crikit.ui.widget_ALS
   :members:
   :undoc-members:
   :show-inheritance:

crikit.ui.widget\_ArPLS module
------------------------------

.. automodule:: crikit.ui.widget_ArPLS
   :members:
   :undoc-members:
   :show-inheritance:

crikit.ui.widget\_Calibrate module
----------------------------------

.. automodule:: crikit.ui.widget_Calibrate
   :members:
   :undoc-members:
   :show-inheritance:

crikit.ui.widget\_Cut\_every\_n\_spectra module
-----------------------------------------------

.. automodule:: crikit.ui.widget_Cut_every_n_spectra
   :members:
   :undoc-members:
   :show-inheritance:

crikit.ui.widget\_DeTrending module
-----------------------------------

.. automodule:: crikit.ui.widget_DeTrending
   :members:
   :undoc-members:
   :show-inheritance:

crikit.ui.widget\_Jupyter module
--------------------------------

.. automodule:: crikit.ui.widget_Jupyter
   :members:
   :undoc-members:
   :show-inheritance:

crikit.ui.widget\_KK module
---------------------------

.. automodule:: crikit.ui.widget_KK
   :members:
   :undoc-members:
   :show-inheritance:

crikit.ui.widget\_SG module
---------------------------

.. automodule:: crikit.ui.widget_SG
   :members:
   :undoc-members:
   :show-inheritance:

crikit.ui.widget\_images module
-------------------------------

.. automodule:: crikit.ui.widget_images
   :members:
   :undoc-members:
   :show-inheritance:

crikit.ui.widget\_mergeNRBs module
----------------------------------

.. automodule:: crikit.ui.widget_mergeNRBs
   :members:
   :undoc-members:
   :show-inheritance:

crikit.ui.widget\_scientificspin module
---------------------------------------

.. automodule:: crikit.ui.widget_scientificspin
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: crikit.ui
   :members:
   :undoc-members:
   :show-inheritance:
